<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nn">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About iTALC</source>
        <translation type="unfinished">Om iTALC</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished">Om</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;http://italc.sourceforge.net&quot;&gt;http://italc.sourceforge.net&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authors</source>
        <translation type="unfinished">Forfattarar</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation type="unfinished">Omsetjing</translation>
    </message>
    <message>
        <source>Current language not translated yet (or native English).

If you&apos;re interested in translating iTALC into your local or another language or want to improve an existing translation, please contact an iTALC developer!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License</source>
        <translation type="unfinished">Lisens</translation>
    </message>
    <message>
        <source>iTALC - Intelligent Teaching And Learning with Computers

Copyright © 2004-2013 Tobias Doerffel / iTALC Solutions</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AccessDialogSlave</name>
    <message>
        <source>Never for this session</source>
        <translation type="unfinished">Aldri for denne økta</translation>
    </message>
    <message>
        <source>Always for this session</source>
        <translation type="unfinished">Alltid denne økta</translation>
    </message>
    <message>
        <source>Confirm desktop access</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The user %1 at host %2 wants to access your desktop. Do you want to grant access?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClassroomManager</name>
    <message>
        <source>Classroom-Manager</source>
        <translation type="unfinished">Klasseromshandterar</translation>
    </message>
    <message>
        <source>Use this workspace to manage your computers and classrooms in an easy way.</source>
        <translation type="unfinished">Bruk dette området til å handtere maskinar og klasserom.</translation>
    </message>
    <message>
        <source>This is where computers and classrooms are managed. You can add computers or classrooms by clicking right in this list.</source>
        <translation type="unfinished">Her handterar du maskinar og klasserom. Bruk høgre musetast i lista for å legge til maskinar eller klasserom.</translation>
    </message>
    <message>
        <source>Classrooms/computers</source>
        <translation type="unfinished">Klasserom / maskiner</translation>
    </message>
    <message>
        <source>IP-address</source>
        <translation type="unfinished">IP-adresse</translation>
    </message>
    <message>
        <source>Usernames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show usernames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the context-menu (right mouse-button) to add/remove computers and/or classrooms.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export to text-file</source>
        <translation type="unfinished">Eksporter til tekstfil</translation>
    </message>
    <message>
        <source>Use this button for exporting this list of computers and usernames into a text-file. You can use this file later for collecting files after an exam has finished. This is sometimes necessary, because some users might have finished and logged out earlier and so you cannot collect their files at the end of the exam.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide teacher computers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show/hide</source>
        <translation type="unfinished">Vis / Gøym</translation>
    </message>
    <message>
        <source>Edit settings</source>
        <translation type="unfinished">Endre innstillingar</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished">Fjern</translation>
    </message>
    <message>
        <source>Show all computers in classroom</source>
        <translation type="unfinished">Vis alle maskinane i klasseromet</translation>
    </message>
    <message>
        <source>Hide all computers in classroom</source>
        <translation type="unfinished">Gøym alle maskinane frå klasseromet</translation>
    </message>
    <message>
        <source>Edit name</source>
        <translation type="unfinished">Endre namn</translation>
    </message>
    <message>
        <source>Remove classroom</source>
        <translation type="unfinished">Fjern klasserom</translation>
    </message>
    <message>
        <source>Add computer</source>
        <translation type="unfinished">Legg til maskin</translation>
    </message>
    <message>
        <source>Add classroom</source>
        <translation type="unfinished">Legg til klasserom</translation>
    </message>
    <message>
        <source>No configuration-file found</source>
        <translation type="unfinished">Klarte ikkje finna oppsettsfila</translation>
    </message>
    <message>
        <source>Could not open configuration file %1.
You will have to add at least one classroom and computers using the classroom-manager which you&apos;ll find inside the program in the sidebar on the left side.</source>
        <translation type="unfinished">Klarte ikkje opne oppsettfila %1. 
Du må leggje til minst eit klasserom og ein maskin i klasseromshandteraren.</translation>
    </message>
    <message>
        <source>Error in configuration-file</source>
        <translation type="unfinished">Oppsettsfila inneheld feil</translation>
    </message>
    <message>
        <source>Error while parsing configuration-file %1.
Please edit it. Otherwise you should delete this file and have to add all classrooms and computers again.</source>
        <translation type="unfinished">Feil med gjennomgang av oppsetts-fila %1. 
Endre den eller slett den og legg til maskinar og klasserom igjen.</translation>
    </message>
    <message>
        <source>Error while parsing configuration-file %1.
Please edit it. Otherwise you should delete this file.</source>
        <translation type="unfinished">Feil med gjennomgang av oppsetts-fila %1. 
Endre den eller slett.</translation>
    </message>
    <message>
        <source>Select output-file</source>
        <translation type="unfinished">Vel filnamn</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation type="unfinished">Tekstfil (*.txt)</translation>
    </message>
    <message>
        <source>Actions for selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Actions</source>
        <translation type="unfinished">Handlingar</translation>
    </message>
    <message>
        <source>Actions for %1</source>
        <translation type="unfinished">Handlingar for %1</translation>
    </message>
    <message>
        <source>New name for classroom</source>
        <translation type="unfinished">Endre namn på klasserom</translation>
    </message>
    <message>
        <source>Please enter a new name for classroom &quot;%1&quot;.</source>
        <translation type="unfinished">Skriv inn nytt namn for klasserom &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>Are you sure want to remove classroom &quot;%1&quot;?
All computers in it will be removed as well!</source>
        <translation type="unfinished">Vil du verkeleg slette klasserom &quot;%1&quot;?
Alle maskiner i klasserom blir også fjerna!</translation>
    </message>
    <message>
        <source>Missing classroom</source>
        <translation type="unfinished">Mangler klasserom</translation>
    </message>
    <message>
        <source>Before adding computers you have to create at least one classroom.
Do you want to create a new classrom now?</source>
        <translation type="unfinished">Før du kan leggje til maskiner må du ha minst eit klasserom.
Vil du lage eit klasserom no?</translation>
    </message>
    <message>
        <source>New classroom</source>
        <translation type="unfinished">Nytt klasserom</translation>
    </message>
    <message>
        <source>Please enter the name of the classroom you want to create.</source>
        <translation type="unfinished">Skriv inn namn på klasserommet du lager.</translation>
    </message>
</context>
<context>
    <name>Client</name>
    <message>
        <source>Unknown state</source>
        <translation type="unfinished">Ukjend status</translation>
    </message>
    <message>
        <source>No user logged in</source>
        <translation type="unfinished">Ingen brukarar logga på</translation>
    </message>
    <message>
        <source>Host unreachable</source>
        <translation type="unfinished">Verten er utilgjengeleg</translation>
    </message>
    <message>
        <source>Demo running</source>
        <translation type="unfinished">Køyrer demonstrasjon</translation>
    </message>
    <message>
        <source>Desktop locked</source>
        <translation type="unfinished">Skrivebordet er låst</translation>
    </message>
</context>
<context>
    <name>ClientAction</name>
    <message>
        <source>Are you sure want logout all users on all visible computers ?</source>
        <translation type="unfinished">Er du sikker på at du vil logge av brukarane på dei synlege maskinane ?</translation>
    </message>
    <message>
        <source>Are you sure want logout all users on all selected computers ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Logout user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure want to reboot all visible computers?</source>
        <translation type="unfinished">Vil du starte alle dei synlege maskinane om at?</translation>
    </message>
    <message>
        <source>Are you sure want to reboot all selected computers?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reboot computers</source>
        <translation type="unfinished">Start maskinane om at</translation>
    </message>
    <message>
        <source>Are you sure want to power down all visible computers?</source>
        <translation type="unfinished">Er du sikker på at du vil skru av alle dei synlege maskinane?</translation>
    </message>
    <message>
        <source>Are you sure want to power down all selected computers?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClientSettingsDialog</name>
    <message>
        <source>Invalid MAC-address</source>
        <translation type="unfinished">Ugyldig MAC-adresse</translation>
    </message>
    <message>
        <source>You specified an invalid MAC-address. Either leave the field blank or enter a valid MAC-address (use &quot;:&quot; as separator!).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Client settings</source>
        <translation type="unfinished">Klient oppsett</translation>
    </message>
    <message>
        <source>IP/hostname</source>
        <translation type="unfinished">IP / Vertnamn</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;enter an IP-address or hostname under which iTALC can reach the client (use &apos;:&apos; for specifying an optional port-number)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">Namn</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Optional nickname of the host which is displayed in iTALC.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MAC address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Hardware/MAC-address of client - only used for powering on client&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Classroom</source>
        <translation type="unfinished">Klasserom</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Student computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Teacher computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other/undefined computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing IP address/hostname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You didn&apos;t specify an IP address or hostname for the computer!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Config</name>
    <message>
        <source>Interval between updates</source>
        <translation type="unfinished">Intervall for oppdateringar</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Here you can set the interval between updates of clients. Higher values result in lower network-traffic and lower CPU-usage on this computer.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> seconds</source>
        <translation type="unfinished"> sekunder</translation>
    </message>
    <message>
        <source>User interface</source>
        <translation type="unfinished">Brukergrensesnitt</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Do not show balloon-tooltips for toolbar-buttons&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Ikkje vis ballongtips for arbeidslinjeknappar&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Check this option if you&apos;re annoyed by the balloon-tooltips appearing when moving mouse-cursor over toolbar-buttons.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Kontroller denne instillinga hvis du er plaga av ballongtips som kjem opp medan du beveger muspeikaren over knappar.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>No balloon-tooltips</source>
        <translation type="unfinished">Ingen ballongtips</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Do not show texts on toolbar-buttons&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No texts on toolbar-buttons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your role (needs according keys!)</source>
        <translation type="unfinished">Din rolle (treng tilsvarande nøklar!)</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Here you can select your role. Only change this if you know what you&apos;re doing. Otherwise you won&apos;t be able to access any clients until you restore your old role.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Teacher</source>
        <translation type="unfinished">Lærar</translation>
    </message>
    <message>
        <source>Administrator</source>
        <translation type="unfinished">Administrator</translation>
    </message>
    <message>
        <source>Supporter</source>
        <translation type="unfinished">Støtte</translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished">Anna</translation>
    </message>
    <message>
        <source>Settings for multi-logon</source>
        <translation type="unfinished">Oppsett for pålogging av fleire brukarar om gongen</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation type="unfinished">Domene</translation>
    </message>
    <message>
        <source>Double-click action for client-window</source>
        <translation type="unfinished">Dobbelklikk handling for klient-vindauge</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Here you can set what should happen if you double-click a client-window.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;p, li { white-space: pre-wrap; }&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Her vel du kva som skal skje når du dobbeltklikker på ei klient-vindauge.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation type="unfinished">Fjernkontroll</translation>
    </message>
    <message>
        <source>View live in fullscreen</source>
        <translation type="unfinished">Vis sanntidsbilete i fullskjerm</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-style:italic;&quot;&gt;Please note, that some changes won&apos;t take effect until you restart iTALC.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-style:italic;&quot;&gt;Nokre endringar trer ikkje i kraft før du startar iTALC om att.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ar - العربية</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cs - Česky</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>de - Deutsch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>el - Ελληνικά</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>es - Español</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fi - Suomi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fr - Français</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>he - עִבְרִית</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hu - Magyar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>it - Italiano</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>nl - Nederlands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>nn - Norsk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pl - Polski</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pt_br - Brasileiro</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pt_pt - Português</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ru - Русский</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sk - Slovenský</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sl - Slovenčina</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sv - Svenska</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>tr - Türkçe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>uk - Українська</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zh_cn - 简体字</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zh_tw - 簡體字</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigWidget</name>
    <message>
        <source>Your iTALC-configuration</source>
        <translation type="unfinished">iTALC oppsett</translation>
    </message>
    <message>
        <source>In this workspace you can customize iTALC to fit your needs.</source>
        <translation type="unfinished">I dette arbeidsområdet endrar du iTALC etter eige behov.</translation>
    </message>
</context>
<context>
    <name>DecoratedMessageBox</name>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
</context>
<context>
    <name>DemoClient</name>
    <message>
        <source>iTALC Demo</source>
        <translation type="unfinished">iTALC Demo</translation>
    </message>
</context>
<context>
    <name>ItalcCoreServer</name>
    <message>
        <source>Authentication error</source>
        <translation type="unfinished">Autentiseringsfeil</translation>
    </message>
    <message>
        <source>Somebody (IP: %1) tried to access this computer but could not authenticate itself successfully!</source>
        <translation type="unfinished">Nokon (IP: %1) prøvde å få tilgang til denne maskina men kunne ikkje autentisera seg!</translation>
    </message>
</context>
<context>
    <name>ItalcVncConnection</name>
    <message>
        <source>VNC authentication failed because of too many authentication tries.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VNC authentication failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VNC server closed connection.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KeyFileAssistant</name>
    <message>
        <source>iTALC Access Key Assistant</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create/import iTALC access keys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This assistant will help you to create or import iTALC access keys.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>How does it work?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>iTALC access keys consist of two parts belonging together, a private and a public key part.

Using the private key part, users on the master computer will be able to access client computers. It is important that only authorized users have read access to the private key file.

The public key part is used on the client computers to verify that any incoming connection request is authorized.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Assistant mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please choose whether to create new access keys or import a public key on a client.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create new access keys (master computer)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>assistantModeButtonGroup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import public key (client computer)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select user role</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please select a user role for which to create or import the access keys:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Teacher</source>
        <translation type="unfinished">Lærar</translation>
    </message>
    <message>
        <source>Administrator</source>
        <translation type="unfinished">Administrator</translation>
    </message>
    <message>
        <source>Support team member</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished">Anna</translation>
    </message>
    <message>
        <source>User roles allow using multiple access keys in parallel. For example there can be different teacher access keys for each classroom while the support access keys are the same for the whole school.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export public key part (master computer)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use custom destination directory for access keys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please specify the location of the public access key to be imported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Summary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The following actions will be taken:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>• Create new access keys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>• Import public access key from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;unknown&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>• Write access key(s) to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>• Export public key to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>• Configure for user role</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select directory in which to export the public key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Key files (*.key.txt)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid public key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selected file does not contain a valid public iTALC access key!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select destination directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Access key creation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not remove previously existing file %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed exporting public access key from %1 to %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Access keys were created and written successfully to %1 and %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An error occured while creating the access keys. You probably are not permitted to write to the selected directories.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Public key import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An error occured while importing the public access key. You probably are not permitted to read the source key or to write the destination file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The public key was successfully imported to %1.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>screen lock</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LogonGroupEditor</name>
    <message>
        <source>Logon group editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please add the groups whose members should be allowed to access computers in your iTALC network.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All groups</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Groups with iTALC privileges</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>Actions</source>
        <translation type="unfinished">Handlingar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished">Avslutt</translation>
    </message>
    <message>
        <source>iTALC Management Console</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>iTALC Server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paths</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>iTALC Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide tray icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autostart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Additional arguments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>State:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Logging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log file directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nothing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only critical messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Errors and critical messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warnings and errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Information, warnings and errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Debug messages and everything else</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Limit log file size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear all log files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Desktop capturing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable capturing of layered (semi-transparent) windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low accuracy (turbo mode)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Demo server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Core server port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Demo server port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable firewall exception</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configuration files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Global configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Personal configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Data directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snapshots</source>
        <translation type="unfinished">Skjermskot</translation>
    </message>
    <message>
        <source>Authentication methods</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Access key management</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Logon settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save settings into file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save settings into file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>L&amp;oad settings from file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About iTALC</source>
        <translation type="unfinished">Om iTALC</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>toolBar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>iTALC Management Console %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load settings from file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XML files (*.xml)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save settings to file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsaved settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There are unsaved settings. Quit anyway?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configuration not writable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The local configuration backend reported that the configuration is not writable! Please run the iTALC Management Console with higher privileges.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All settings were applied successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An error occured while applying settings!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>iTALC</source>
        <translation type="unfinished">iTALC</translation>
    </message>
    <message>
        <source>No write access</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not read/write or create directory %1! For running iTALC, make sure you&apos;re permitted to create or write this directory.</source>
        <translation type="unfinished">Klarte ikkje lesa/skriva eller lage katalog %1! Kontroller at du har nødvendig tilgang for å lage eller skrive til denne katalogen før du køyrer iTALC.</translation>
    </message>
    <message>
        <source>Classroom</source>
        <translation type="unfinished">Klasserom</translation>
    </message>
    <message>
        <source>Switch classroom</source>
        <translation type="unfinished">Bytt klasserom</translation>
    </message>
    <message>
        <source>Click this button to open a menu where you can choose the active classroom.</source>
        <translation type="unfinished">Trykk her for å opne meny med val av aktivt klasserom.</translation>
    </message>
    <message>
        <source>Click on this button, to switch between classrooms.</source>
        <translation type="unfinished">Trykk denne knappen for å byte mellom klasserom.</translation>
    </message>
    <message>
        <source>Overview mode</source>
        <translation type="unfinished">Oversiktsmodus</translation>
    </message>
    <message>
        <source>Overview</source>
        <translation type="unfinished">Oversikt</translation>
    </message>
    <message>
        <source>This is the default mode in iTALC and allows you to have an overview over all visible computers. Also click on this button for unlocking locked workstations or for leaving demo-mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fullscreen demo</source>
        <translation type="unfinished">Fullskjerm demonstrasjon</translation>
    </message>
    <message>
        <source>Fullscreen Demo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop Demo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In this mode your screen is being displayed on all shown computers. Furthermore the users aren&apos;t able to do something else as all input devices are locked in this mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window demo</source>
        <translation type="unfinished">Demonstrasjon i vindauge</translation>
    </message>
    <message>
        <source>Window Demo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In this mode your screen being displayed in a window on all shown computers. The users are able to switch to other windows and thus can continue to work.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lock/unlock desktops</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lock all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unlock all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>To have all user&apos;s full attention you can lock their desktops using this button. In this mode all input devices are locked and the screen is black.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send text message</source>
        <translation type="unfinished">Send tekstmelding</translation>
    </message>
    <message>
        <source>Text message</source>
        <translation type="unfinished">Tekstmelding</translation>
    </message>
    <message>
        <source>Use this button to send a text message to all users e.g. to tell them new tasks etc.</source>
        <translation type="unfinished">Bruk denne knappen for å sende tekstmeldingar til alle brukarane td. gje beskjed om ei ny oppgåve.</translation>
    </message>
    <message>
        <source>Power on computers</source>
        <translation type="unfinished">Skru på maskinar</translation>
    </message>
    <message>
        <source>Power on</source>
        <translation type="unfinished">Skru på</translation>
    </message>
    <message>
        <source>Click this button to power on all visible computers. This way you do not have to turn on each computer by hand.</source>
        <translation type="unfinished">Trykk denne knappen for å skru på alle dei synlege maskinane på ein gong.</translation>
    </message>
    <message>
        <source>Power down computers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Power down</source>
        <translation type="unfinished">Skru av</translation>
    </message>
    <message>
        <source>To power down all shown computers (e.g. after the lesson has finished) you can click this button.</source>
        <translation type="unfinished">Trykk her for å skru av alle synlege maskinar (td. etter ein time eller i slutten av dagen).</translation>
    </message>
    <message>
        <source>Support</source>
        <translation type="unfinished">Støtte</translation>
    </message>
    <message>
        <source>Direct support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you need to support someone at a certain computer you can click this button and enter the according hostname or IP afterwards.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Adjust/align</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Adjust windows and their size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When clicking this button the biggest possible size for the client-windows is adjusted. Furthermore all windows are aligned.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto re-arrange windows and their size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When clicking this button all visible windows are re-arranged and adjusted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>iTALC Master Control</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation type="unfinished">Fjernkontroll</translation>
    </message>
    <message>
        <source>Could not modify the autostart property for the iTALC Service.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not modify the service arguments for the iTALC Service.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not change the firewall configuration for the iTALC Service.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Debugging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable desktop switching for screen lock (experimental)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log to standard error output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log to Windows event log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VNC reflector</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>iTALC 1 demo server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Multithreading (can be enabled when using the VNC reflector backend)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable HTTP server which provides a JavaViewer applet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HTTP server port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow connections from localhost only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Key file authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ACL-based logon authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Public key file base directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Private key file base directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Launch key file assistant</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage permissions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Test</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Access confirmation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can configure iTALC to ask the user for permission to access the desktop when using certain authentication methods.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Logon authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow same user to access desktop without confirmation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Debugging iTALC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When encountering bugs or other misbehaviour in iTALC it is important to inform the developers about them, so that the bugs can be fixed in future releases. This page allows you to submit a helpful bug report easily.

If the bug is not reproducible, skip step 1) - 3).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear the logfiles in the &quot;General&quot; section.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In the &quot;General&quot; section set the log level to &quot;Debug messages and everything else&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Repeat the actions leading to the bug or misbehaviour.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click the following button and save the file to a known location.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Generate bug report archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go to the &lt;a href=&quot;http://sourceforge.net/tracker/?group_id=132465&amp;amp;atid=724375&quot;&gt;iTALC bug tracker&lt;/a&gt;, open a new bug, describe what you did in step 3) and attach the file you saved in step 4).&lt;/p&gt;
&lt;br/&gt;
&lt;br/&gt;
Note: if the bug involves both a master and client computer, attach bug report archives for both computers.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restart iTALC Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All settings were saved successfully. In order to take effect the iTALC service needs to be restarted. Restart it now?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Starting iTALC service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stopping iTALC service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The iTALC service needs to be stopped temporarily in order to remove the log files. Continue?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log files cleared</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All log files were cleared successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not remove all log files.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Logon authentication test</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication with provided credentials was successful.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication with provided credentials failed!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save bug report archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>iTALC bug report archive (*.ibra.xml)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>iTALC bug report archive saved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An iTALC bug report archive has been saved to %1. It includes iTALC log files and information about your operating system. You can attach it to a bug report.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not contact iTALC service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not contact the local iTALC service. It is likely that you entered wrong credentials or key files are not set up properly. Try again or contact your administrator for solving this problem using the iTALC Management Console.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication impossible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No authentication key files were found or your current ones are outdated. Please create new key files using the iTALC Management Console. Alternatively set up logon authentication using the iTALC Management Console. Otherwise you won&apos;t be able to access computers using iTALC.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Poll full screen (leave this enabled per default)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageBoxSlave</name>
    <message>
        <source>Message from teacher</source>
        <translation type="unfinished">Beskjed frå lærar</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600; font-style:italic;&quot;&gt;Welcome to iTALC!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;p, li { white-space: pre-wrap; }&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600; font-style:italic;&quot;&gt;Velkommen til iTALC &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Here you see the working-bar which contains several buttons. Each button is connected to a workspace. Just take a look at the available workspaces by clicking on the corresponding button.</source>
        <translation type="unfinished">Dette er dei forskjellege arbeidsråda. Kvar knapp er kobla opp mot eit arbeidsområde. Trykk på knappane for å sjå gjennom dei.</translation>
    </message>
    <message>
        <source>Using the classroom-manager you can manage your classrooms and computers. You can also see which users are logged in.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The snapshot-workspace is a very useful tool. It let&apos;s you manage the snapshots you made.</source>
        <translation type="unfinished">Skjermskot arbeidsområdet lar deg behandle og sjå skjermskot du har laga.</translation>
    </message>
    <message>
        <source>Of course you can configure iTALC. This is usually done using the configuration-workspace.</source>
        <translation type="unfinished">Endringar i oppsettet til iTALC blir for det meste gjort i arbeidsområdet for oppsett.</translation>
    </message>
    <message>
        <source>About iTALC</source>
        <translation type="unfinished">Om iTALC</translation>
    </message>
</context>
<context>
    <name>OverviewWidget</name>
    <message>
        <source>Overview</source>
        <translation type="unfinished">Oversikt</translation>
    </message>
    <message>
        <source>Some basic information on iTALC and how to use it.</source>
        <translation type="unfinished">Grunnleggjande informasjon om iTALC og korleis det kan brukast.</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Please enter your username and password in order to access iTALC clients.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished">Brukarnamn</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished">Passord</translation>
    </message>
    <message>
        <source>iTALC Logon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Unable to register service &apos;%1&apos;.</source>
        <translation>Klarte ikkje registrere tenesta &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not registered.</source>
        <translation>Klarte ikkje å kontakte tenestebehandlaren (har du dei nødvendige rettighetene ?) - Tenesta &apos;%1&apos; blei ikkje registrert.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; is already registered.</source>
        <translation>Tenesta &apos;%1&apos; er allereie registrert.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be registered.</source>
        <translation>Klarte ikkje registrere tenesta &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; was successfully registered.</source>
        <translation>Tenesta &apos;%1&apos; er no registrert.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be stopped.</source>
        <translation>Klarte ikkje stoppe tenesten &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; has been unregistered.</source>
        <translation>Tenesta &apos;%1&apos; er fjerna.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; isn&apos;t registered and therefore can&apos;t be unregistered.</source>
        <translation>Tenesta &apos;%1&apos; er ikkje registrert og kan difor ikkje fernast.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be unregistered.</source>
        <translation>Klarte ikkje fjerne tenesta &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be found.</source>
        <translation>Klarte ikkje finne tenesta &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not unregistered.</source>
        <translation>Klarte ikkje å kontakte tenestebehandlaren (har du dei nødvendige rettighetene ?) - Tenesta &apos;%1&apos; blei ikkje fjerna.</translation>
    </message>
    <message>
        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not stopped.</source>
        <translation>Klarte ikkje å kontakte tenestebehandlaren (har du dei nødvendige rettighetene ?) - Tenesta &apos;%1&apos; blei ikkje stoppa.</translation>
    </message>
    <message>
        <source>iTALC Client %1 on %2:%3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RemoteControlWidget</name>
    <message>
        <source>View live (%1 @ %2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remote control (%1 @ %2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown user</source>
        <translation type="unfinished">Ukjent brukar</translation>
    </message>
</context>
<context>
    <name>RemoteControlWidgetToolBar</name>
    <message>
        <source>View only</source>
        <translation type="unfinished">Berre vis bilete</translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation type="unfinished">Fjernkontroll</translation>
    </message>
    <message>
        <source>Lock student</source>
        <translation type="unfinished">Lås elev/student</translation>
    </message>
    <message>
        <source>Unlock student</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation type="unfinished">Skjermskot</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished">Fullskjerm</translation>
    </message>
    <message>
        <source>Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished">Avslutt</translation>
    </message>
    <message>
        <source>Connecting %1</source>
        <translation type="unfinished">Koplar til %1</translation>
    </message>
    <message>
        <source>Connected.</source>
        <translation type="unfinished">Tilkobla.</translation>
    </message>
</context>
<context>
    <name>RemoteLogonDialog</name>
    <message>
        <source>Remote logon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the fields below to enter the username, password and optional the domain name. These information will be used to logon the computer(s).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished">Brukarnamn</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished">Passord</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation type="unfinished">Domene</translation>
    </message>
</context>
<context>
    <name>RunCommandsDialog</name>
    <message>
        <source>Run commands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please enter the commands to run on the selected client(s). You can separate multiple commands by line.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Snapshot</name>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not take a snapshot as directory %1 doesn&apos;t exist and couldn&apos;t be created.</source>
        <translation type="unfinished">Klarte ikkje lage skjermskot då katalogen %1 verken finnes eller kunne opprettast.</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation type="unfinished">Skjermskot</translation>
    </message>
</context>
<context>
    <name>SnapshotList</name>
    <message>
        <source>Snapshots</source>
        <translation type="unfinished">Skjermskot</translation>
    </message>
    <message>
        <source>Simply manage the snapshots you made using this workspace.</source>
        <translation type="unfinished">Dette arbeidsområdet er til å handtere skjermskot.</translation>
    </message>
</context>
<context>
    <name>Snapshots</name>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;All snapshots you made are listed here. You can make snapshots by selecting the according entry in the context-menu of a client-window. These snapshosts can be managed using the buttons below.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;p, li { white-space: pre-wrap; }&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Alle skjermskota du har laga er her. Lag fleire skjermskot med hjelp av oppsprettmenyen på klient-vindauge. Knappane under er til å handtera skjermskota. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>User:</source>
        <translation type="unfinished">Brukar:</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation type="unfinished">Vert:</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation type="unfinished">Dato:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation type="unfinished">Tid:</translation>
    </message>
    <message>
        <source>Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SupportDialog</name>
    <message>
        <source>Support</source>
        <translation type="unfinished">Støtte</translation>
    </message>
    <message>
        <source>Please enter the IP address or the name of the host to which you want to connect.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextMessageDialog</name>
    <message>
        <source>Send text message</source>
        <translation type="unfinished">Send tekstmelding</translation>
    </message>
    <message>
        <source>Use the field below to type your message which will be sent to all selected users.</source>
        <translation type="unfinished">Skriv beskjed til alle valte brukarar i feltet under her.</translation>
    </message>
</context>
<context>
    <name>VncView</name>
    <message>
        <source>Establishing connection to %1 ...</source>
        <translation type="unfinished">Kobler til %1 ...</translation>
    </message>
</context>
<context>
    <name>clientMenu</name>
    <message>
        <source>Overview</source>
        <translation type="unfinished">Oversikt</translation>
    </message>
    <message>
        <source>Fullscreen demo</source>
        <translation type="unfinished">Fullskjerm demonstrasjon</translation>
    </message>
    <message>
        <source>Window demo</source>
        <translation type="unfinished">Demonstrasjon i vindauge</translation>
    </message>
    <message>
        <source>Locked display</source>
        <translation type="unfinished">Lås skjermbilete</translation>
    </message>
    <message>
        <source>View live</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation type="unfinished">Fjernkontroll</translation>
    </message>
    <message>
        <source>Let student show demo</source>
        <translation type="unfinished">La elev vise demonstrasjon</translation>
    </message>
    <message>
        <source>Send text message</source>
        <translation type="unfinished">Send tekstmelding</translation>
    </message>
    <message>
        <source>Logout user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Take a snapshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Power on</source>
        <translation type="unfinished">Skru på</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="unfinished">Start om att</translation>
    </message>
    <message>
        <source>Power down</source>
        <translation type="unfinished">Skru av</translation>
    </message>
    <message>
        <source>Execute commands</source>
        <translation type="unfinished">Køyr kommando</translation>
    </message>
</context>
</TS>
